==> 0.1.97.tar.gz: lib/network_resources/repository/auth_repo.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:flutter/foundation.dart';
import 'package:oowoo_core/theme/theme.dart';
import 'package:oowoo_core/utils/utils.dart';
import '../../utils/device_infos.dart';
import '../resources.dart';

class UpdateInfoResult {
  bool status;
  String? msg;

  UpdateInfoResult({required this.status, this.msg});
}

class CheckNewEmailProResult {
  bool status;
  String? msg;
  String? thumbnail;
  String? displayName;
  dynamic roleId;

  CheckNewEmailProResult(
      {required this.status,
      this.msg,
      this.displayName,
      this.roleId,
      this.thumbnail});
}

class AuthRepo {
  AuthRepo._();

  static AuthRepo? _instance;

  factory AuthRepo([AppApi? api]) {
    _instance ??= AuthRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;
  final _firebaseAuth = FirebaseAuth.instance;

  ///Phone on MOBILE
  Future<void> verifyPhoneNumber(
      {required String phoneNumber,
      required PhoneVerificationCompleted verificationCompleted,
      required PhoneVerificationFailed verificationFailed,
      required PhoneCodeSent codeSent,
      required PhoneCodeAutoRetrievalTimeout codeAutoRetrievalTimeout,
      String? autoRetrievedSmsCodeForTesting,
      Duration timeout = const Duration(seconds: 30),
      int? forceResendingToken}) {
    return _firebaseAuth.verifyPhoneNumber(
        phoneNumber: phoneNumber,
        verificationCompleted: verificationCompleted,
        verificationFailed: verificationFailed,
        codeSent: codeSent,
        timeout: Duration(seconds: 90),
        codeAutoRetrievalTimeout: codeAutoRetrievalTimeout);
  }

  ///Phone on WEB
  Future<ConfirmationResult?> signInWithPhoneNumber(String phone) async {
    try {
      ConfirmationResult confirmationResult =
          await _firebaseAuth.signInWithPhoneNumber(phone);
      return confirmationResult;
    } catch (e) {
      appDebugPrint(e);
    }
  }

  Future<UserCredential> confirmationResult(
          ConfirmationResult confirmationResult, String code) =>
      confirmationResult.confirm(code);

  ///=============
  Future<UserCredential> signInWithCredential(AuthCredential credential) =>
      _firebaseAuth.signInWithCredential(credential);

  Future<UserCredential> signInWithEmailPassword(
          String email, String password) =>
      _firebaseAuth.signInWithEmailAndPassword(
          email: email, password: password);

  /// API
  Future<bool> checkNewPhoneFromPro(phone) async {
    NetworkResponse response = await _api.checkNewPhoneFromPro(phone);
    return response.data ?? false;
  }

  Future<bool> checkNewPhoneFromUser(phone) async {
    NetworkResponse response = await _api.checkNewPhoneFromUser(phone);
    return response.data ?? false;
  }

  Future<UserModel?> checkExistPhoneFromUser(phone) async {
    NetworkResponse response = await _api.checkExistPhoneFromUser(phone);
    return response.data;
  }

  Future<bool> updateNewUserPasswordByFirebase(params) async {
    NetworkResponse response =
        await _api.updateNewUserPasswordByFirebase(params);
    return response.data ?? false;
  }

  Future<Map> _addParams(params) async {
    String? notificationToken;
    try {
      if (kIsWeb) {
        notificationToken =
            await FirebaseMessaging.instance.getToken(vapidKey: vapidKey);
      } else {
        notificationToken = await FirebaseMessaging.instance.getToken();
      }
    } catch (e) {
      appDebugPrint(e);
    }
    Map realParams = Map.from(params);
    realParams.addAll({
      'allowPrivacyTypeId': 1,
      'platformId': valuePlatformByConfig(),
      'dashboard': 'oowoo',
      "notificationToken": notificationToken,
      "notificationProvider": "fcm",
    });
    if (isPlatformStateInitialized) {
      realParams.addAll({'deviceInfos': deviceData});
    }
    return realParams;
  }

  Future<Map> _addParamsOnlyPlatformId(params) async {
    Map realParams = Map.from(params);
    realParams.addAll({
      'platformId': valuePlatformByConfig(),
    });
    return realParams;
  }

  Future<NetworkResponse> loginUserByPhone(params) async {
    return await _api.loginUserByPhone(await _addParams(params));
  }

  Future<Token?> loginUserByEmail(params) async {
    NetworkResponse response =
        await _api.loginUserByEmail(await _addParams(params));
    return response.data;
  }

  Future<Token?> createOrLoginPro(params) async {
    NetworkResponse response =
        await _api.createOrLoginPro(await _addParams(params));
    return response.data;
  }

  Future<Token?> createNewUser(params) async {
    NetworkResponse response =
        await _api.createNewUser(await _addParams(params));
    return response.data;
  }

  Future<Token?> subRegisterUser() async {
    NetworkResponse response =
        await _api.subRegisterUser(await _addParamsOnlyPlatformId({}));
    return response.data;
  }

  Future<ProInfo?> getProInfo() async {
    NetworkResponse response = await _api.getProInfo();
    return response.data;
  }

  Future<UserModel?> getUserInfo() async {
    NetworkResponse response = await _api.getUserInfo();
    return response.data;
  }

  Future<bool> updatePro(params) async {
    NetworkResponse response = await _api.updatePro(params);
    return response.data ?? false;
  }

  Future<UpdateInfoResult> updateUser(params) async {
    NetworkResponse response = await _api.updateUser(params);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<bool?> updateProPwd(
      {required String oldPassword, required String newPassword}) async {
    NetworkResponse response =
        await _api.updateProPwd(oldPassword, newPassword);
    return response.data == true;
  }

  Future<String?> setThumbnailForPro(image, filePath) async {
    NetworkResponse response = await _api.setThumbnailForPro(image, filePath);
    return response.data;
  }

  Future<String?> setThumbnailForUser(image, filePath) async {
    NetworkResponse response = await _api.setThumbnailForUser(image, filePath);
    return response.data;
  }

  Future<Token?> refreshUserToken(String refresh) async {
    NetworkResponse response = await _api.refreshUserToken(refresh);
    return response.data;
  }

  Future<Token?> refreshProToken(String refresh) async {
    NetworkResponse response = await _api.refreshProToken(refresh);
    return response.data;
  }

  Future<bool> addNotificationToken([fcmToken, provider]) async {
    try {
      if (fcmToken == null) {
        if (kIsWeb) {
          fcmToken = await FirebaseMessaging.instance
              .getToken(vapidKey: firebaseOptions?.apiKey);
        } else {
          fcmToken = await FirebaseMessaging.instance.getToken();
        }
        provider = 'fcm';
      }
      Map<String, dynamic> params = {
        'fcmToken': fcmToken,
        "dashboard": "oowoo",
        "provider": provider
      };
      NetworkResponse response = await _api.addNotificationToken(params);
      return response.data ?? false;
    } catch (e) {
      appDebugPrint('addNotificationToken: $e');
      return false;
    }
  }

  Future<bool> logoutPro([fcmToken]) async {
    NetworkResponse response = await _api.logoutPro(fcmToken);
    return response.data ?? false;
  }

  Future<bool> logoutUser([fcmToken]) async {
    NetworkResponse response = await _api.logoutUser(fcmToken);
    return response.data ?? false;
  }

  Future<NetworkResponse> checkUpdateEmailFromUser(email) async {
    return await _api.checkUpdateEmailFromUser(
        await _addParamsOnlyPlatformId({'email': email}));
  }

  Future<NetworkResponse> confirmUpdateUserEmailCode(email, code, phone) async {
    return await _api.confirmUpdateUserEmailCode(email, code, phone);
  }

  Future<bool> updateUserEmail(token) async {
    NetworkResponse response = await _api.updateUserEmail(token);
    return response.data ?? false;
  }

  Future<NetworkResponse> checkUpdateEmailFromPro(email) async {
    return await _api.checkUpdateEmailFromPro(
        await _addParamsOnlyPlatformId({'email': email}));
  }

  Future<NetworkResponse> confirmUpdateProEmailCode(email, code) async {
    return await _api.confirmUpdateProEmailCode(email, code);
  }

  Future<bool> updateProEmail(token) async {
    NetworkResponse response = await _api.updateProEmail(token);
    return response.data ?? false;
  }

  Future<NetworkResponse> loginPro(params) async {
    return await _api.loginPro(await _addParams(params));
  }

  Future<NetworkResponse> loginUserByPhoneAndFirebase(params) async {
    return await _api.loginUserByPhoneAndFirebase(await _addParams(params));
  }

  Future<NetworkResponse> loginProByPhoneAndFirebase(params) async {
    return await _api.loginProByPhoneAndFirebase(await _addParams(params));
  }

  Future<Token?> loginProCrmByQrCode(params) async {
    NetworkResponse response =
        await _api.loginProCrmByQrCode(await _addParams(params));
    return response.data;
  }

  Future<Token?> createOrLoginUser(params) async {
    NetworkResponse response =
        await _api.createOrLoginUser(await _addParams(params));
    return response.data;
  }

  Future<CheckNewEmailProResult?> checkEmailPro(email) async {
    NetworkResponse response = await _api.checkEmailPro({"email": email});
    return response.data;
  }

  Future<CheckNewEmailProResult?> checkNewProEmail(email) async {
    NetworkResponse response = await _api.checkNewProEmail({
      "email": email,
      'allowPrivacyTypeId': 1,
      'platformId': valuePlatformByConfig(),
      'dashboard': 'oowoo'
    });
    return response.data;
  }

  Future<bool> checkLoginProByEmailOTP(email) async {
    NetworkResponse response = await _api.checkLoginProByEmailOTP({
      "email": email,
      'platformId': valuePlatformByConfig(),
    });
    return response.data ?? false;
  }

  Future loginProByEmailOTPConfirm(params) async {
    return await _api.loginProByEmailOTPConfirm(await _addParams(params));
  }

  Future<ConfirmOtp?> confirmNewProCode({email, code}) async {
    NetworkResponse response = await _api.confirmNewProCode({
      "email": email,
      "code": code,
    });
    return response.data;
  }

  Future<ConfirmOtp?> confirmResetProPasswordCode({email, code}) async {
    NetworkResponse response = await _api.confirmResetProPasswordCode({
      "email": email,
      "code": code,
    });
    return response.data;
  }

  Future<bool> updateNewProPasswordByToken({password, token}) async {
    NetworkResponse response = await _api.updateNewProPasswordByToken({
      "password": password,
      "token": token,
    });
    return response.data;
  }

  Future<Token?> createNewPro(params) async {
    NetworkResponse response =
        await _api.createNewPro(await _addParams(params));
    return response.data;
  }

  Future<List<MainCat>> getCategoriesList() async {
    NetworkResponse response = await _api.getCategoriesList();
    return response.data ?? [];
  }

  Future<bool> checkExistEmailFromPro(email) async {
    NetworkResponse response = await _api.checkExistEmailFromPro({
      "email": email,
    });
    return response.data ?? false;
  }

  Future<bool> resetProPassword(email) async {
    NetworkResponse response = await _api.resetProPassword(_addParams({
      "email": email,
      'allowPrivacyTypeId': 1,
      'platformId': valuePlatformByConfig(),
      'dashboard': 'oowoo'
    }));
    return response.data ?? false;
  }

  Future<ProsModel?> getProInfoByUniqueId(uniqueId) async {
    NetworkResponse response = await _api.getProInfoByUniqueId(uniqueId);
    return response.data;
  }

  Future<UserModel?> getUserInfoByFirebaseId(firebaseId) async {
    NetworkResponse response = await _api.getUserInfoByFirebaseId(firebaseId);
    return response.data;
  }

  Future<ProsModel?> getProInfoByFirebaseId(firebaseId) async {
    NetworkResponse response = await _api.getProInfoByFirebaseId(firebaseId);
    return response.data;
  }

  Future<OrgProInfo?> getAssetsForProFromUniversalDashboard(proUniqueId) async {
    NetworkResponse response =
        await _api.getAssetsForProFromUniversalDashboard(proUniqueId);
    return response.data;
  }
}

==> 0.2.9.tar.gz: lib/network_resources/repository/auth_repo.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:flutter/foundation.dart';
import 'package:oowoo_core/theme/theme.dart';
import 'package:oowoo_core/utils/utils.dart';
import '../../utils/device_infos.dart';
import '../resources.dart';

class UpdateInfoResult {
  bool status;
  String? msg;

  UpdateInfoResult({required this.status, this.msg});
}

class CheckNewEmailProResult {
  bool status;
  String? msg;
  String? thumbnail;
  String? displayName;
  dynamic roleId;

  CheckNewEmailProResult(
      {required this.status,
      this.msg,
      this.displayName,
      this.roleId,
      this.thumbnail});
}

class AuthRepo {
  AuthRepo._();

  static AuthRepo? _instance;

  factory AuthRepo([AppApi? api]) {
    _instance ??= AuthRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;
  final _firebaseAuth = FirebaseAuth.instance;

  ///Phone on MOBILE
  Future<void> verifyPhoneNumber(
      {required String phoneNumber,
      required PhoneVerificationCompleted verificationCompleted,
      required PhoneVerificationFailed verificationFailed,
      required PhoneCodeSent codeSent,
      required PhoneCodeAutoRetrievalTimeout codeAutoRetrievalTimeout,
      String? autoRetrievedSmsCodeForTesting,
      Duration timeout = const Duration(seconds: 30),
      int? forceResendingToken}) {
    return _firebaseAuth.verifyPhoneNumber(
        phoneNumber: phoneNumber,
        verificationCompleted: verificationCompleted,
        verificationFailed: verificationFailed,
        codeSent: codeSent,
        timeout: Duration(seconds: 90),
        codeAutoRetrievalTimeout: codeAutoRetrievalTimeout);
  }

  ///Phone on WEB
  Future<ConfirmationResult?> signInWithPhoneNumber(String phone) async {
    try {
      ConfirmationResult confirmationResult =
          await _firebaseAuth.signInWithPhoneNumber(phone);
      return confirmationResult;
    } catch (e) {
      appDebugPrint(e);
    }
  }

  Future<UserCredential> confirmationResult(
          ConfirmationResult confirmationResult, String code) =>
      confirmationResult.confirm(code);

  ///=============
  Future<UserCredential> signInWithCredential(AuthCredential credential) =>
      _firebaseAuth.signInWithCredential(credential);

  Future<UserCredential> signInWithEmailPassword(
          String email, String password) =>
      _firebaseAuth.signInWithEmailAndPassword(
          email: email, password: password);

  /// API
  Future<bool> checkNewPhoneFromPro(phone) async {
    NetworkResponse response = await _api.checkNewPhoneFromPro(phone);
    return response.data ?? false;
  }

  Future<bool> checkNewPhoneFromUser(phone) async {
    NetworkResponse response = await _api.checkNewPhoneFromUser(phone);
    return response.data ?? false;
  }

  Future<UserModel?> checkExistPhoneFromUser(phone) async {
    NetworkResponse response = await _api.checkExistPhoneFromUser(phone);
    return response.data;
  }

  Future<bool> updateNewUserPasswordByFirebase(params) async {
    NetworkResponse response =
        await _api.updateNewUserPasswordByFirebase(params);
    return response.data ?? false;
  }

  Future<Map> _addParams(params) async {
    String? notificationToken;
    try {
      if (kIsWeb) {
        notificationToken =
            await FirebaseMessaging.instance.getToken(vapidKey: vapidKey);
      } else {
        notificationToken = await FirebaseMessaging.instance.getToken();
      }
    } catch (e) {
      appDebugPrint(e);
    }
    Map realParams = Map.from(params);
    realParams.addAll({
      'allowPrivacyTypeId': 1,
      'platformId': valuePlatformByConfig(),
      'dashboard': 'oowoo',
      "notificationToken": notificationToken,
      "notificationProvider": "fcm",
    });
    if (isPlatformStateInitialized) {
      realParams.addAll({'deviceInfos': deviceData});
    }
    return realParams;
  }

  Future<Map> _addParamsOnlyPlatformId(params) async {
    Map realParams = Map.from(params);
    realParams.addAll({
      'platformId': valuePlatformByConfig(),
    });
    return realParams;
  }

  Future<NetworkResponse> loginUserByPhone(params) async {
    return await _api.loginUserByPhone(await _addParams(params));
  }

  Future<Token?> loginUserByEmail(params) async {
    NetworkResponse response =
        await _api.loginUserByEmail(await _addParams(params));
    return response.data;
  }

  Future<Token?> createOrLoginPro(params) async {
    NetworkResponse response =
        await _api.createOrLoginPro(await _addParams(params));
    return response.data;
  }

  Future<Token?> createNewUser(params) async {
    NetworkResponse response =
        await _api.createNewUser(await _addParams(params));
    return response.data;
  }

  Future<Token?> subRegisterUser() async {
    NetworkResponse response =
        await _api.subRegisterUser(await _addParamsOnlyPlatformId({}));
    return response.data;
  }

  Future<ProInfo?> getProInfo() async {
    NetworkResponse response = await _api.getProInfo();
    return response.data;
  }

  Future<UserModel?> getUserInfo() async {
    NetworkResponse response = await _api.getUserInfo();
    return response.data;
  }

  Future<bool> updatePro(params) async {
    NetworkResponse response = await _api.updatePro(params);
    return response.data ?? false;
  }

  Future<UpdateInfoResult> updateUser(params) async {
    NetworkResponse response = await _api.updateUser(params);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<bool?> updateProPwd(
      {required String oldPassword, required String newPassword}) async {
    NetworkResponse response =
        await _api.updateProPwd(oldPassword, newPassword);
    return response.data == true;
  }

  Future<String?> setThumbnailForPro(image, filePath) async {
    NetworkResponse response = await _api.setThumbnailForPro(image, filePath);
    return response.data;
  }

  Future<String?> setThumbnailForUser(image, filePath) async {
    NetworkResponse response = await _api.setThumbnailForUser(image, filePath);
    return response.data;
  }

  Future<Token?> refreshUserToken(String refresh) async {
    NetworkResponse response = await _api.refreshUserToken(refresh);
    return response.data;
  }

  Future<Token?> refreshProToken(String refresh) async {
    NetworkResponse response = await _api.refreshProToken(refresh);
    return response.data;
  }

  Future<bool> addNotificationToken([fcmToken, provider]) async {
    try {
      if (fcmToken == null) {
        if (kIsWeb) {
          fcmToken = await FirebaseMessaging.instance
              .getToken(vapidKey: firebaseOptions?.apiKey);
        } else {
          fcmToken = await FirebaseMessaging.instance.getToken();
        }
        provider = 'fcm';
      }
      Map<String, dynamic> params = {
        'fcmToken': fcmToken,
        "dashboard": "oowoo",
        "provider": provider
      };
      NetworkResponse response = await _api.addNotificationToken(params);
      return response.data ?? false;
    } catch (e) {
      appDebugPrint('addNotificationToken: $e');
      return false;
    }
  }

  Future<bool> logoutPro([fcmToken]) async {
    NetworkResponse response = await _api
        .logoutPro(await _addParamsOnlyPlatformId({'fcmToken': fcmToken}));
    return response.data ?? false;
  }

  Future<bool> logoutUser([fcmToken]) async {
    NetworkResponse response = await _api
        .logoutUser(await _addParamsOnlyPlatformId({'fcmToken': fcmToken}));
    return response.data ?? false;
  }

  Future<NetworkResponse> checkUpdateEmailFromUser(email) async {
    return await _api.checkUpdateEmailFromUser(
        await _addParamsOnlyPlatformId({'email': email}));
  }

  Future<NetworkResponse> confirmUpdateUserEmailCode(email, code, phone) async {
    return await _api.confirmUpdateUserEmailCode(email, code, phone);
  }

  Future<bool> updateUserEmail(token) async {
    NetworkResponse response = await _api.updateUserEmail(token);
    return response.data ?? false;
  }

  Future<NetworkResponse> checkUpdateEmailFromPro(email) async {
    return await _api.checkUpdateEmailFromPro(
        await _addParamsOnlyPlatformId({'email': email}));
  }

  Future<NetworkResponse> confirmUpdateProEmailCode(email, code) async {
    return await _api.confirmUpdateProEmailCode(email, code);
  }

  Future<bool> updateProEmail(token) async {
    NetworkResponse response = await _api.updateProEmail(token);
    return response.data ?? false;
  }

  Future<NetworkResponse> loginPro(params) async {
    return await _api.loginPro(await _addParams(params));
  }

  Future<NetworkResponse> loginUserByPhoneAndFirebase(params) async {
    return await _api.loginUserByPhoneAndFirebase(await _addParams(params));
  }

  Future<NetworkResponse> loginProByPhoneAndFirebase(params) async {
    return await _api.loginProByPhoneAndFirebase(await _addParams(params));
  }

  Future<Token?> loginProCrmByQrCode(params) async {
    NetworkResponse response =
        await _api.loginProCrmByQrCode(await _addParams(params));
    return response.data;
  }

  Future<Token?> createOrLoginUser(params) async {
    NetworkResponse response =
        await _api.createOrLoginUser(await _addParams(params));
    return response.data;
  }

  Future<CheckNewEmailProResult?> checkEmailPro(email) async {
    NetworkResponse response = await _api.checkEmailPro({"email": email});
    return response.data;
  }

  Future<CheckNewEmailProResult?> checkNewProEmail(email) async {
    NetworkResponse response = await _api.checkNewProEmail({
      "email": email,
      'allowPrivacyTypeId': 1,
      'platformId': valuePlatformByConfig(),
      'dashboard': 'oowoo'
    });
    return response.data;
  }

  Future<bool> checkLoginProByEmailOTP(email) async {
    NetworkResponse response = await _api.checkLoginProByEmailOTP({
      "email": email,
      'platformId': valuePlatformByConfig(),
    });
    return response.data ?? false;
  }

  Future loginProByEmailOTPConfirm(params) async {
    return await _api.loginProByEmailOTPConfirm(await _addParams(params));
  }

  Future<ConfirmOtp?> confirmNewProCode({email, code}) async {
    NetworkResponse response = await _api.confirmNewProCode({
      "email": email,
      "code": code,
    });
    return response.data;
  }

  Future<ConfirmOtp?> confirmResetProPasswordCode({email, code}) async {
    NetworkResponse response = await _api.confirmResetProPasswordCode({
      "email": email,
      "code": code,
    });
    return response.data;
  }

  Future<bool> updateNewProPasswordByToken({password, token}) async {
    NetworkResponse response = await _api.updateNewProPasswordByToken({
      "password": password,
      "token": token,
    });
    return response.data;
  }

  Future<Token?> createNewPro(params) async {
    NetworkResponse response =
        await _api.createNewPro(await _addParams(params));
    return response.data;
  }

  Future<List<MainCat>> getCategoriesList() async {
    NetworkResponse response = await _api.getCategoriesList();
    return response.data ?? [];
  }

  Future<bool> checkExistEmailFromPro(email) async {
    NetworkResponse response = await _api.checkExistEmailFromPro({
      "email": email,
    });
    return response.data ?? false;
  }

  Future<bool> resetProPassword(email) async {
    NetworkResponse response = await _api.resetProPassword(await _addParams({
      "email": email,
      'allowPrivacyTypeId': 1,
      'platformId': valuePlatformByConfig(),
      'dashboard': 'oowoo'
    }));
    return response.data ?? false;
  }

  Future<ProsModel?> getProInfoByUniqueId(uniqueId) async {
    NetworkResponse response = await _api.getProInfoByUniqueId(uniqueId);
    return response.data;
  }

  Future<UserModel?> getUserInfoByFirebaseId(firebaseId) async {
    NetworkResponse response = await _api.getUserInfoByFirebaseId(firebaseId);
    return response.data;
  }

  Future<ProsModel?> getProInfoByFirebaseId(firebaseId) async {
    NetworkResponse response = await _api.getProInfoByFirebaseId(firebaseId);
    return response.data;
  }

  Future<OrgProInfo?> getAssetsForProFromUniversalDashboard(proUniqueId) async {
    NetworkResponse response =
        await _api.getAssetsForProFromUniversalDashboard(proUniqueId);
    return response.data;
  }
}
